@@ -266,6 +266,15 @@ implements MOGroup
 
 
 //--AgentGen BEGIN=_MEMBERS
+  public static final OID oidSnmp4jNotificationLogMode =
+    new OID(new int[] { 1,3,6,1,4,1,4976,10,1,1,1,1,3,0 });
+
+  // Enumerations
+  public static final class Snmp4jNotificationLogModeEnum {
+    public static final int fired = 1;
+    public static final int sent = 2;
+  }
+
   private static final int idxNlmConfigLogViewName = 6;
   private static final int VAR_SYNTAX_LIST[] = {
     SMIConstants.SYNTAX_COUNTER32,
@@ -285,6 +294,9 @@ implements MOGroup
   private TDomainAddressFactory addressFactory = new TDomainAddressFactoryImpl();
   private MOTableRelation nlmStatsLogEntryAugmentation;
   private List nlmLogEntries = new ArrayList();
+
+  private MOScalar snmp4jNotificationLogMode;
+
 //--AgentGen END
 
   /**
@@ -351,6 +363,15 @@ implements MOGroup
       moFactory.createScalar(oidNlmStatsGlobalNotificationsBumped,
                              moFactory.createAccess(MOAccessImpl.ACCESSIBLE_FOR_READ_ONLY),
                              new Counter32());
+    snmp4jNotificationLogMode =
+      moFactory.createScalar(oidSnmp4jNotificationLogMode,
+                             moFactory.createAccess(MOAccessImpl.ACCESSIBLE_FOR_READ_WRITE),
+                             new Integer32(Snmp4jNotificationLogModeEnum.fired));
+    snmp4jNotificationLogMode.addMOValueValidationListener(
+      new ValueConstraintValidator(
+        new EnumerationConstraint(new int[] {
+                                  Snmp4jNotificationLogModeEnum.fired,
+                                  Snmp4jNotificationLogModeEnum.sent })));
     createNlmConfigLogEntry(moFactory);
     createNlmStatsLogEntry(moFactory);
     createNlmLogEntry(moFactory);
@@ -673,6 +694,7 @@ implements MOGroup
     server.register(this.nlmLogEntry, context);
     server.register(this.nlmLogVariableEntry, context);
 //--AgentGen BEGIN=_registerMOs
+    server.register(this.snmp4jNotificationLogMode, context);
 //--AgentGen END
   }
 
@@ -687,6 +709,7 @@ implements MOGroup
     server.unregister(this.nlmLogEntry, context);
     server.unregister(this.nlmLogVariableEntry, context);
 //--AgentGen BEGIN=_unregisterMOs
+    server.unregister(this.snmp4jNotificationLogMode, context);
 //--AgentGen END
   }
 
@@ -1513,65 +1536,105 @@ implements MOGroup
 
 
 //--AgentGen BEGIN=_METHODS
+
+  /**
+   * Sets the log mode of the events. Possible values are defined by
+   * #Snmp4jNotificationLogModeEnum.
+   * @param loggerMode
+   *    1 to set log mode to log fired notification events only,
+   *    2 to set log mode to log sent notifications only.
+   * @since 1.4.2
+   */
+  public void setLogMode(int loggerMode) {
+    snmp4jNotificationLogMode.setValue(new Integer32(loggerMode));
+  }
+
+  /**
+   * Returns the current log mode as defined by #Snmp4jNotificationLogModeEnum.
+   * @return
+   *    1 if fired notification events are logged only,
+   *    2 if sent notifications are logged only.
+   * @since 1.4.2
+   */
+  public int getLogMode() {
+    return snmp4jNotificationLogMode.getValue().toInt();
+  }
+
   public void notificationLogEvent(NotificationLogEvent notificationLogEvent) {
-    Integer32 enabledStatus = new Integer32(NlmConfigLogAdminStatusEnum.enabled);
-    synchronized (nlmConfigLogEntryModel) {
-      for (Iterator it = nlmConfigLogEntryModel.iterator(); it.hasNext();) {
-        NlmConfigLogEntryRow row = (NlmConfigLogEntryRow) it.next();
-        if (enabledStatus.equals(row.getNlmConfigLogAdminStatus())) {
-          OctetString profileName = new OctetString();
-          profileName.fromSubIndex(row.getIndex(), false);
-          OctetString filterName = row.getNlmConfigLogFilterName();
-          if (filterName == null) {
-            continue;
-          }
-          else if ((profileName.length() == 0) ||
-                   (checkAccess(notificationLogEvent.getNotificationID(),
-                                notificationLogEvent.getVariables(), row))) {
-            if ((snmpNotificationMIB.passesFilter(
-                filterName,
-                notificationLogEvent.getNotificationID(),
-                notificationLogEvent.getVariables()))) {
-              if (nextLogIndex > 4294967295L) {
-                nextLogIndex = 1;
-              }
-              else {
-                nextLogIndex++;
-              }
-              while ((nlmLogEntryModel.getRowCount() > 0) &&
-                     (nlmLogEntryModel.lastIndex().last() >= nextLogIndex)) {
-                nextLogIndex++;
-              }
-              OID logIndex = profileName.toSubIndex(false);
-              logIndex.append((int)nextLogIndex & 0xFFFFFFFF);
-              NlmLogEntryRow logRow = (NlmLogEntryRow)
-                  nlmLogEntry.createRow(logIndex,
-                                        new Variable[] {
-                SNMPv2MIB.getSysUpTime(null).get(),
-                DateAndTime.makeDateAndTime(new GregorianCalendar()),
-                notificationLogEvent.getOriginatorEngineID(),
-                addressFactory.getAddress(notificationLogEvent.getOriginatorTarget().getAddress()),
-                addressFactory.getTransportDomain(notificationLogEvent.getOriginatorTarget().getAddress()),
-                notificationLogEvent.getContextEngineID(),
-                notificationLogEvent.getContext(),
-                notificationLogEvent.getNotificationID()
-              });
-              if (nlmLogEntry.addRow(logRow)) {
-                nlmLogEntries.add(logRow.getIndex());
-              }
-              for (int i=0; i<notificationLogEvent.getVariables().length; i++) {
-                addVariable(logIndex, i+1,
-                            notificationLogEvent.getVariables()[i]);
-              }
-              synchronized (nlmStatsLogEntryModel) {
-                NlmStatsLogEntryRow statsRow = (NlmStatsLogEntryRow)
-                    nlmStatsLogEntryModel.getRow(profileName.toSubIndex(false));
-                if (statsRow != null) {
-                  statsRow.getNlmStatsLogNotificationsLogged().increment();
+    if (notificationLogEvent.isSubEvent() ==
+        (getLogMode() == Snmp4jNotificationLogModeEnum.sent)) {
+      Integer32 enabledStatus = new Integer32(NlmConfigLogAdminStatusEnum.
+                                              enabled);
+      synchronized (nlmConfigLogEntryModel) {
+        for (Iterator it = nlmConfigLogEntryModel.iterator(); it.hasNext(); ) {
+          NlmConfigLogEntryRow row = (NlmConfigLogEntryRow) it.next();
+          if (enabledStatus.equals(row.getNlmConfigLogAdminStatus())) {
+            OctetString profileName = new OctetString();
+            profileName.fromSubIndex(row.getIndex(), false);
+            OctetString filterName = row.getNlmConfigLogFilterName();
+            if (filterName == null) {
+              continue;
+            }
+            else if ((profileName.length() == 0) ||
+                     (checkAccess(notificationLogEvent.getNotificationID(),
+                                  notificationLogEvent.getVariables(), row))) {
+              if ((snmpNotificationMIB.passesFilter(
+                  filterName,
+                  notificationLogEvent.getNotificationID(),
+                  notificationLogEvent.getVariables()))) {
+                if (nextLogIndex > 4294967295L) {
+                  nextLogIndex = 1;
                 }
+                else {
+                  nextLogIndex++;
+                }
+                while ((nlmLogEntryModel.getRowCount() > 0) &&
+                       (nlmLogEntryModel.lastIndex().last() >= nextLogIndex)) {
+                  nextLogIndex++;
+                }
+                OID logIndex = profileName.toSubIndex(false);
+                logIndex.append((int) nextLogIndex & 0xFFFFFFFF);
+                OctetString addrString = new OctetString();
+                OID domainOID = new OID();
+                if (notificationLogEvent.getOriginatorTarget() != null) {
+                  Address addr =
+                      notificationLogEvent.getOriginatorTarget().getAddress();
+                  addrString = addressFactory.getAddress(addr);
+                  domainOID = addressFactory.getTransportDomain(addr);
+                }
+                NlmLogEntryRow logRow = (NlmLogEntryRow)
+                    nlmLogEntry.createRow(logIndex,
+                                          new Variable[] {
+                                          SNMPv2MIB.getSysUpTime(null).get(),
+                                          DateAndTime.makeDateAndTime(new
+                    GregorianCalendar()),
+                                          notificationLogEvent.
+                                          getOriginatorEngineID(),
+                                          addrString,
+                                          domainOID,
+                                          notificationLogEvent.getContextEngineID(),
+                                          notificationLogEvent.getContext(),
+                                          notificationLogEvent.getNotificationID()
+                });
+                if (nlmLogEntry.addRow(logRow)) {
+                  nlmLogEntries.add(logRow.getIndex());
+                }
+                for (int i = 0; i < notificationLogEvent.getVariables().length;
+                     i++) {
+                  addVariable(logIndex, i + 1,
+                              notificationLogEvent.getVariables()[i]);
+                }
+                synchronized (nlmStatsLogEntryModel) {
+                  NlmStatsLogEntryRow statsRow = (NlmStatsLogEntryRow)
+                      nlmStatsLogEntryModel.getRow(profileName.toSubIndex(false));
+                  if (statsRow != null) {
+                    statsRow.getNlmStatsLogNotificationsLogged().increment();
+                  }
+                }
+                ((Counter32) nlmStatsGlobalNotificationsLogged.getValue()).
+                    increment();
+                checkLimits(profileName);
               }
-              ((Counter32)nlmStatsGlobalNotificationsLogged.getValue()).increment();
-              checkLimits(profileName);
             }
           }
         }
@@ -1936,6 +1999,19 @@ implements MOGroup
 //--AgentGen END
 
 //--AgentGen BEGIN=_CLASSES
+  /**
+   * The <code>Snmp4jNotificationLogModeValidator</code> implements the value
+   * validation for <code>Snmp4jNotificationLogMode</code>.
+   */
+  static class Snmp4jNotificationLogModeValidator implements MOValueValidationListener {
+
+    public void validate(MOValueValidationEvent validationEvent) {
+      Variable newValue = validationEvent.getNewValue();
+     //--AgentGen BEGIN=snmp4jNotificationLogMode::validate
+
+     //--AgentGen END
+    }
+  }
 //--AgentGen END
 
 //--AgentGen BEGIN=_END
